==> haskell-unsafe-0.0-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unsafe.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unsafe
version:              0.0
visibility:           public
id:                   unsafe-0.0-EouVzQKqugPJ8ZFpriBgYH
key:                  unsafe-0.0-EouVzQKqugPJ8ZFpriBgYH
license:              BSD-3-Clause
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             http://code.haskell.org/~thielema/unsafe/
synopsis:             Unified interface to unsafe functions
description:
    SafeHaskell introduced the notion of safe and unsafe modules.
    In order to make as many as possible modules \"safe\",
    the well-known unsafe functions were moved to distinguished modules.
    This makes it hard to write packages that work
    with both old and new versions of GHC.
    This package provides a single module @System.Unsafe@
    that exports the unsafe functions from the base package.
    It provides them in a style ready for qualification,
    that is, you should import them by

    > import qualified System.Unsafe as Unsafe

    The package also contains a script called @rename-unsafe.sh@.
    It replaces all occurrences of the original identifiers
    with the qualified identifiers from this package.
    You still have to adapt the import commands.
    It uses the @darcs-replace-rec@ script from the @darcs-scripts@ package.

category:             Control
abi:                  4f5db68189381a9fadbe343141af51ba
exposed:              True
exposed-modules:      System.Unsafe
import-dirs:          /usr/lib/ghc-9.2.8/site-local/unsafe-0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/unsafe-0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unsafe
hs-libraries:         HSunsafe-0.0-EouVzQKqugPJ8ZFpriBgYH
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-unsafe/html/unsafe.haddock
haddock-html:         /usr/share/doc/haskell-unsafe/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unsafe-0.0-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unsafe.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unsafe
version:              0.0
visibility:           public
id:                   unsafe-0.0-GQ6Zydb4lCS7B1Ck4GrK4S
key:                  unsafe-0.0-GQ6Zydb4lCS7B1Ck4GrK4S
license:              BSD-3-Clause
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             http://code.haskell.org/~thielema/unsafe/
synopsis:             Unified interface to unsafe functions
description:
    SafeHaskell introduced the notion of safe and unsafe modules.
    In order to make as many as possible modules \"safe\",
    the well-known unsafe functions were moved to distinguished modules.
    This makes it hard to write packages that work
    with both old and new versions of GHC.
    This package provides a single module @System.Unsafe@
    that exports the unsafe functions from the base package.
    It provides them in a style ready for qualification,
    that is, you should import them by

    > import qualified System.Unsafe as Unsafe

    The package also contains a script called @rename-unsafe.sh@.
    It replaces all occurrences of the original identifiers
    with the qualified identifiers from this package.
    You still have to adapt the import commands.
    It uses the @darcs-replace-rec@ script from the @darcs-scripts@ package.

category:             Control
abi:                  e6e041fe2a1b7b3d8fea45729a028a57
exposed:              True
exposed-modules:      System.Unsafe
import-dirs:          /usr/lib/ghc-9.4.8/site-local/unsafe-0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/unsafe-0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/unsafe-0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unsafe
hs-libraries:         HSunsafe-0.0-GQ6Zydb4lCS7B1Ck4GrK4S
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-unsafe/html/unsafe.haddock
haddock-html:         /usr/share/doc/haskell-unsafe/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
